VerifierMerkleTranscriptChannel

Struct VerifierMerkleTranscriptChannel 

pub struct VerifierMerkleTranscriptChannel<T, Challenger_, F, H: HashSuite> { /* private fields */ }
A MerkleIPVerifierChannel over a VerifierTranscript, verifying openings with a BinaryMerkleTreeScheme.

The transcript is held through a BorrowMut bound, so the channel can own the transcript or mutably borrow one.

Implementations

Source

impl<T, Challenger_, F, H: HashSuite> VerifierMerkleTranscriptChannel<T, Challenger_, F, H>

pub fn new(transcript: T) -> Self

Constructs a channel over the transcript with a default Merkle tree scheme.

pub const fn with_scheme( transcript: T, scheme: BinaryMerkleTreeScheme<F, H>, ) -> Self

Constructs a channel over the transcript with the given Merkle tree scheme.

pub fn into_transcript(self) -> T

Returns the wrapped transcript.